# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from accessibletranslator.models.target_languages_response import TargetLanguagesResponse
from accessibletranslator.models.transformations_response import TransformationsResponse
from accessibletranslator.models.translation_request import TranslationRequest
from accessibletranslator.models.translation_response import TranslationResponse

from accessibletranslator.api_client import ApiClient, RequestSerialized
from accessibletranslator.api_response import ApiResponse
from accessibletranslator.rest import RESTResponseType


class TranslationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def target_languages(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TargetLanguagesResponse:
        """Get Available Target Languages

        Get a list of all supported target languages for translation  Returns a comprehensive list of all supported target languages that can be used with the /api/translate endpoint for translating simplified output to different languages.  Returns:     Dictionary with languages list and metadata      Example response:     {         \"languages\": [\"Same as input\", \"English\", \"French\", \"German\", \"Spanish\", ...],         \"total_languages\": 10,         \"usage_note\": \"Use 'Same as input' to keep output in source language, or specify target language\"     }

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._target_languages_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TargetLanguagesResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def target_languages_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TargetLanguagesResponse]:
        """Get Available Target Languages

        Get a list of all supported target languages for translation  Returns a comprehensive list of all supported target languages that can be used with the /api/translate endpoint for translating simplified output to different languages.  Returns:     Dictionary with languages list and metadata      Example response:     {         \"languages\": [\"Same as input\", \"English\", \"French\", \"German\", \"Spanish\", ...],         \"total_languages\": 10,         \"usage_note\": \"Use 'Same as input' to keep output in source language, or specify target language\"     }

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._target_languages_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TargetLanguagesResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def target_languages_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Available Target Languages

        Get a list of all supported target languages for translation  Returns a comprehensive list of all supported target languages that can be used with the /api/translate endpoint for translating simplified output to different languages.  Returns:     Dictionary with languages list and metadata      Example response:     {         \"languages\": [\"Same as input\", \"English\", \"French\", \"German\", \"Spanish\", ...],         \"total_languages\": 10,         \"usage_note\": \"Use 'Same as input' to keep output in source language, or specify target language\"     }

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._target_languages_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TargetLanguagesResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _target_languages_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/target-languages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def transformations(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TransformationsResponse:
        """Get Available Transformations

        Get a list of all available text transformations  Returns a comprehensive list of all transformation options that can be used with the /api/translate endpoint, including their documentation strings.  Returns:     Dictionary with transformations list and metadata      Example response:     {         \"transformations\": [             {                 \"name\": \"language_literal\",                 \"description\": \"Use literal language. Avoid metaphors, idioms, sarcasm, and figurative speech.\"             },             ...         ],         \"total_count\": 51,         \"special_transformations\": [\"explain_changes\"]     }

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._transformations_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TransformationsResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def transformations_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TransformationsResponse]:
        """Get Available Transformations

        Get a list of all available text transformations  Returns a comprehensive list of all transformation options that can be used with the /api/translate endpoint, including their documentation strings.  Returns:     Dictionary with transformations list and metadata      Example response:     {         \"transformations\": [             {                 \"name\": \"language_literal\",                 \"description\": \"Use literal language. Avoid metaphors, idioms, sarcasm, and figurative speech.\"             },             ...         ],         \"total_count\": 51,         \"special_transformations\": [\"explain_changes\"]     }

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._transformations_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TransformationsResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def transformations_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Available Transformations

        Get a list of all available text transformations  Returns a comprehensive list of all transformation options that can be used with the /api/translate endpoint, including their documentation strings.  Returns:     Dictionary with transformations list and metadata      Example response:     {         \"transformations\": [             {                 \"name\": \"language_literal\",                 \"description\": \"Use literal language. Avoid metaphors, idioms, sarcasm, and figurative speech.\"             },             ...         ],         \"total_count\": 51,         \"special_transformations\": [\"explain_changes\"]     }

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._transformations_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TransformationsResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _transformations_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/transformations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def translate(
        self,
        translation_request: TranslationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TranslationResponse:
        """Translate Text

        Translate text according to user-selected accessibility transformations  Main API endpoint for text translation. Takes input text and transformation options, checks the user's word balance, processes the text using AI, and records usage statistics. The word balance is charged based on input text word count.  Authentication:     Supports both JWT tokens (web UI) and API keys (programmatic access).          API Key Usage:     - Authorization header: \"Authorization: Bearer sk_your_api_key_here\"     - X-API-Key header: \"X-API-Key: sk_your_api_key_here\"  Args:     request: TranslationRequest with text and transformations     current_user: Authenticated user from flexible authentication (JWT or API key)     db: Database session dependency      Returns:     Dictionary with comprehensive translation results:     {         \"translated_text\": \"The processed text with transformations applied\",         \"explanations\": \"Detailed explanations if requested, or null\",         \"input_language\": \"Detected language of the input text\",         \"output_language\": \"Target language ('Same as input' uses detected language)\",         \"input_word_count\": 123,         \"processing_time_ms\": 15234,         \"word_balance\": 877,         \"words_used\": 123     }  Example API Key Usage:     curl -H \"Authorization: Bearer sk_your_api_key_here\" \\          -H \"Content-Type: application/json\" \\          -d '{\"text\": \"Complex text\", \"transformations\": [\"language_simple_sentences\"]}' \\          https://api.yourdomain.com/api/translate      Raises:     HTTPException(402): If user has insufficient word balance     HTTPException(500): For any other processing errors

        :param translation_request: (required)
        :type translation_request: TranslationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_serialize(
            translation_request=translation_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TranslationResponse",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def translate_with_http_info(
        self,
        translation_request: TranslationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TranslationResponse]:
        """Translate Text

        Translate text according to user-selected accessibility transformations  Main API endpoint for text translation. Takes input text and transformation options, checks the user's word balance, processes the text using AI, and records usage statistics. The word balance is charged based on input text word count.  Authentication:     Supports both JWT tokens (web UI) and API keys (programmatic access).          API Key Usage:     - Authorization header: \"Authorization: Bearer sk_your_api_key_here\"     - X-API-Key header: \"X-API-Key: sk_your_api_key_here\"  Args:     request: TranslationRequest with text and transformations     current_user: Authenticated user from flexible authentication (JWT or API key)     db: Database session dependency      Returns:     Dictionary with comprehensive translation results:     {         \"translated_text\": \"The processed text with transformations applied\",         \"explanations\": \"Detailed explanations if requested, or null\",         \"input_language\": \"Detected language of the input text\",         \"output_language\": \"Target language ('Same as input' uses detected language)\",         \"input_word_count\": 123,         \"processing_time_ms\": 15234,         \"word_balance\": 877,         \"words_used\": 123     }  Example API Key Usage:     curl -H \"Authorization: Bearer sk_your_api_key_here\" \\          -H \"Content-Type: application/json\" \\          -d '{\"text\": \"Complex text\", \"transformations\": [\"language_simple_sentences\"]}' \\          https://api.yourdomain.com/api/translate      Raises:     HTTPException(402): If user has insufficient word balance     HTTPException(500): For any other processing errors

        :param translation_request: (required)
        :type translation_request: TranslationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_serialize(
            translation_request=translation_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TranslationResponse",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def translate_without_preload_content(
        self,
        translation_request: TranslationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Translate Text

        Translate text according to user-selected accessibility transformations  Main API endpoint for text translation. Takes input text and transformation options, checks the user's word balance, processes the text using AI, and records usage statistics. The word balance is charged based on input text word count.  Authentication:     Supports both JWT tokens (web UI) and API keys (programmatic access).          API Key Usage:     - Authorization header: \"Authorization: Bearer sk_your_api_key_here\"     - X-API-Key header: \"X-API-Key: sk_your_api_key_here\"  Args:     request: TranslationRequest with text and transformations     current_user: Authenticated user from flexible authentication (JWT or API key)     db: Database session dependency      Returns:     Dictionary with comprehensive translation results:     {         \"translated_text\": \"The processed text with transformations applied\",         \"explanations\": \"Detailed explanations if requested, or null\",         \"input_language\": \"Detected language of the input text\",         \"output_language\": \"Target language ('Same as input' uses detected language)\",         \"input_word_count\": 123,         \"processing_time_ms\": 15234,         \"word_balance\": 877,         \"words_used\": 123     }  Example API Key Usage:     curl -H \"Authorization: Bearer sk_your_api_key_here\" \\          -H \"Content-Type: application/json\" \\          -d '{\"text\": \"Complex text\", \"transformations\": [\"language_simple_sentences\"]}' \\          https://api.yourdomain.com/api/translate      Raises:     HTTPException(402): If user has insufficient word balance     HTTPException(500): For any other processing errors

        :param translation_request: (required)
        :type translation_request: TranslationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_serialize(
            translation_request=translation_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TranslationResponse",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _translate_serialize(
        self,
        translation_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if translation_request is not None:
            _body_params = translation_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/translate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.models.user_profile_response import UserProfileResponse

class TestUserProfileResponse(unittest.TestCase):
    """UserProfileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserProfileResponse:
        """Test UserProfileResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserProfileResponse`
        """
        model = UserProfileResponse()
        if include_optional:
            return UserProfileResponse(
                user_id = 56,
                username = '',
                email = '',
                user_type = '',
                is_admin = True,
                word_balance = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return UserProfileResponse(
                user_id = 56,
                username = '',
                email = '',
                user_type = '',
                is_admin = True,
                word_balance = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testUserProfileResponse(self):
        """Test UserProfileResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TranslationResponse(BaseModel):
    """
    Response model for text translation API
    """ # noqa: E501
    translated_text: StrictStr
    explanations: Optional[StrictStr] = None
    input_language: StrictStr
    output_language: StrictStr
    input_word_count: StrictInt
    processing_time_ms: StrictInt
    word_balance: StrictInt
    words_used: StrictInt
    __properties: ClassVar[List[str]] = ["translated_text", "explanations", "input_language", "output_language", "input_word_count", "processing_time_ms", "word_balance", "words_used"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TranslationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if explanations (nullable) is None
        # and model_fields_set contains the field
        if self.explanations is None and "explanations" in self.model_fields_set:
            _dict['explanations'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TranslationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "translated_text": obj.get("translated_text"),
            "explanations": obj.get("explanations"),
            "input_language": obj.get("input_language"),
            "output_language": obj.get("output_language"),
            "input_word_count": obj.get("input_word_count"),
            "processing_time_ms": obj.get("processing_time_ms"),
            "word_balance": obj.get("word_balance"),
            "words_used": obj.get("words_used")
        })
        return _obj





# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.models.translation_response import TranslationResponse

class TestTranslationResponse(unittest.TestCase):
    """TranslationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TranslationResponse:
        """Test TranslationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TranslationResponse`
        """
        model = TranslationResponse()
        if include_optional:
            return TranslationResponse(
                translated_text = '',
                explanations = '',
                input_language = '',
                output_language = '',
                input_word_count = 56,
                processing_time_ms = 56,
                word_balance = 56,
                words_used = 56
            )
        else:
            return TranslationResponse(
                translated_text = '',
                input_language = '',
                output_language = '',
                input_word_count = 56,
                processing_time_ms = 56,
                word_balance = 56,
                words_used = 56,
        )
        """

    def testTranslationResponse(self):
        """Test TranslationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.models.target_languages_response import TargetLanguagesResponse

class TestTargetLanguagesResponse(unittest.TestCase):
    """TargetLanguagesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TargetLanguagesResponse:
        """Test TargetLanguagesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TargetLanguagesResponse`
        """
        model = TargetLanguagesResponse()
        if include_optional:
            return TargetLanguagesResponse(
                languages = [
                    ''
                    ],
                total_languages = 56,
                usage_note = ''
            )
        else:
            return TargetLanguagesResponse(
                languages = [
                    ''
                    ],
                total_languages = 56,
                usage_note = '',
        )
        """

    def testTargetLanguagesResponse(self):
        """Test TargetLanguagesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.api.user_management_api import UserManagementApi


class TestUserManagementApi(unittest.IsolatedAsyncioTestCase):
    """UserManagementApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = UserManagementApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_word_balance(self) -> None:
        """Test case for word_balance

        Get Word Balance
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from accessibletranslator.api.system_api import SystemApi
from accessibletranslator.api.translation_api import TranslationApi
from accessibletranslator.api.user_management_api import UserManagementApi




# coding: utf-8

# flake8: noqa

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.0"

# Define package exports
__all__ = [
    "SystemApi",
    "TranslationApi",
    "UserManagementApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BasicHealthCheck",
    "FunctionInfo",
    "HTTPValidationError",
    "TargetLanguagesResponse",
    "TokenVerificationResponse",
    "TransformationInfo",
    "TransformationsResponse",
    "TranslationRequest",
    "TranslationResponse",
    "UserProfileResponse",
    "ValidationError",
    "ValidationErrorLocInner",
    "WordBalanceResponse",
]

# import apis into sdk package
from accessibletranslator.api.system_api import SystemApi as SystemApi
from accessibletranslator.api.translation_api import TranslationApi as TranslationApi
from accessibletranslator.api.user_management_api import UserManagementApi as UserManagementApi

# import ApiClient
from accessibletranslator.api_response import ApiResponse as ApiResponse
from accessibletranslator.api_client import ApiClient as ApiClient
from accessibletranslator.configuration import Configuration as Configuration
from accessibletranslator.exceptions import OpenApiException as OpenApiException
from accessibletranslator.exceptions import ApiTypeError as ApiTypeError
from accessibletranslator.exceptions import ApiValueError as ApiValueError
from accessibletranslator.exceptions import ApiKeyError as ApiKeyError
from accessibletranslator.exceptions import ApiAttributeError as ApiAttributeError
from accessibletranslator.exceptions import ApiException as ApiException

# import models into sdk package
from accessibletranslator.models.basic_health_check import BasicHealthCheck as BasicHealthCheck
from accessibletranslator.models.function_info import FunctionInfo as FunctionInfo
from accessibletranslator.models.http_validation_error import HTTPValidationError as HTTPValidationError
from accessibletranslator.models.target_languages_response import TargetLanguagesResponse as TargetLanguagesResponse
from accessibletranslator.models.token_verification_response import TokenVerificationResponse as TokenVerificationResponse
from accessibletranslator.models.transformation_info import TransformationInfo as TransformationInfo
from accessibletranslator.models.transformations_response import TransformationsResponse as TransformationsResponse
from accessibletranslator.models.translation_request import TranslationRequest as TranslationRequest
from accessibletranslator.models.translation_response import TranslationResponse as TranslationResponse
from accessibletranslator.models.user_profile_response import UserProfileResponse as UserProfileResponse
from accessibletranslator.models.validation_error import ValidationError as ValidationError
from accessibletranslator.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner
from accessibletranslator.models.word_balance_response import WordBalanceResponse as WordBalanceResponse



# coding: utf-8

# flake8: noqa
"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from accessibletranslator.models.basic_health_check import BasicHealthCheck
from accessibletranslator.models.function_info import FunctionInfo
from accessibletranslator.models.http_validation_error import HTTPValidationError
from accessibletranslator.models.target_languages_response import TargetLanguagesResponse
from accessibletranslator.models.token_verification_response import TokenVerificationResponse
from accessibletranslator.models.transformation_info import TransformationInfo
from accessibletranslator.models.transformations_response import TransformationsResponse
from accessibletranslator.models.translation_request import TranslationRequest
from accessibletranslator.models.translation_response import TranslationResponse
from accessibletranslator.models.user_profile_response import UserProfileResponse
from accessibletranslator.models.validation_error import ValidationError
from accessibletranslator.models.validation_error_loc_inner import ValidationErrorLocInner
from accessibletranslator.models.word_balance_response import WordBalanceResponse



# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.api.translation_api import TranslationApi


class TestTranslationApi(unittest.IsolatedAsyncioTestCase):
    """TranslationApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TranslationApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_target_languages(self) -> None:
        """Test case for target_languages

        Get Available Target Languages
        """
        pass

    async def test_transformations(self) -> None:
        """Test case for transformations

        Get Available Transformations
        """
        pass

    async def test_translate(self) -> None:
        """Test case for translate

        Translate Text
        """
        pass


if __name__ == '__main__':
    unittest.main()
